screenveil library

Classes

BlurVeilOptions
Configuration options for the blur-style screen veil.
CustomVeilOptions
Configuration options for the custom widget-style screen veil.
ImageVeilOptions
Configuration options for the image-style screen veil.
ScreenVeil
A wrapper widget that hides sensitive application content when the app enters background/inactive lifecycle states, or when forced programmatically.
VeilOptions
Base configuration options for a screen veil.

Enums

VeilType
The type of protective veil to apply when the application screen is hidden.