CustomVeilOptions class
Configuration options for the custom widget-style screen veil.
- Inheritance
-
- Object
- VeilOptions
- CustomVeilOptions
Constructors
- CustomVeilOptions({required Widget child})
-
const
Properties
- child → Widget
-
A builder function or direct widget to render when the app is obscured.
This can be a security splash screen, passcode input, or simple branding.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited